package sun.java2d.d3d;

import java.awt.LinearGradientPaint;
import java.awt.MultipleGradientPaint;
import sun.java2d.SurfaceData;
import java.awt.image.BufferedImage;
import sun.java2d.loops.CompositeType;
import java.awt.TexturePaint;
import java.util.HashMap;
import sun.java2d.SunGraphics2D;
import java.util.Map;

abstract class D3DPaints
{
    private static Map<Integer, D3DPaints> impls;
    
    D3DPaints() {
    }
    
    static boolean isValid(SunGraphics2D sunGraphics2D) {
        D3DPaints d3DPaints = (D3DPaints)D3DPaints.impls.get(Integer.valueOf(sunGraphics2D.paintState));
        return d3DPaints != null && d3DPaints.isPaintValid(sunGraphics2D);
    }
    
    abstract boolean isPaintValid(SunGraphics2D p0);
    
    static {
        (D3DPaints.impls = new HashMap(4, 1.0f)).put(Integer.valueOf(2), new D3DPaints.Gradient());
        D3DPaints.impls.put(Integer.valueOf(3), new D3DPaints.LinearGradient());
        D3DPaints.impls.put(Integer.valueOf(4), new D3DPaints.RadialGradient());
        D3DPaints.impls.put(Integer.valueOf(5), new D3DPaints.Texture());
    }
    
    private static class Gradient extends D3DPaints
    {
        @Override
        boolean isPaintValid(SunGraphics2D sunGraphics2D) {
            return ((D3DGraphicsDevice)((D3DSurfaceData)sunGraphics2D.surfaceData).getDeviceConfiguration().getDevice()).isCapPresent(65536);
        }
    }
    
    private static class Texture extends D3DPaints
    {
        public boolean isPaintValid(SunGraphics2D sunGraphics2D) {
            TexturePaint texturePaint = (TexturePaint)sunGraphics2D.paint;
            D3DSurfaceData d3DSurfaceData = (D3DSurfaceData)sunGraphics2D.surfaceData;
            BufferedImage image = texturePaint.getImage();
            D3DGraphicsDevice d3DGraphicsDevice = (D3DGraphicsDevice)d3DSurfaceData.getDeviceConfiguration().getDevice();
            int width = image.getWidth();
            int height = image.getHeight();
            if (!d3DGraphicsDevice.isCapPresent(32) && ((width & width - 1) != 0x0 || (height & height - 1) != 0x0)) {
                return false;
            }
            if (!d3DGraphicsDevice.isCapPresent(64) && width != height) {
                return false;
            }
            SurfaceData surfaceData = d3DSurfaceData.getSourceSurfaceData(image, 0, CompositeType.SrcOver, null);
            if (!(surfaceData instanceof D3DSurfaceData)) {
                surfaceData = d3DSurfaceData.getSourceSurfaceData(image, 0, CompositeType.SrcOver, null);
                if (!(surfaceData instanceof D3DSurfaceData)) {
                    return false;
                }
            }
            return ((D3DSurfaceData)surfaceData).getType() == 3;
        }
    }
    
    private abstract static class MultiGradient extends D3DPaints
    {
        public static final int MULTI_MAX_FRACTIONS_D3D = 8;
        
        protected MultiGradient() {
        }
        
        @Override
        boolean isPaintValid(SunGraphics2D sunGraphics2D) {
            return ((MultipleGradientPaint)sunGraphics2D.paint).getFractions().length <= 8 && ((D3DGraphicsDevice)((D3DSurfaceData)sunGraphics2D.surfaceData).getDeviceConfiguration().getDevice()).isCapPresent(65536);
        }
    }
    
    private static class LinearGradient extends D3DPaints.MultiGradient
    {
        @Override
        boolean isPaintValid(SunGraphics2D sunGraphics2D) {
            LinearGradientPaint linearGradientPaint = (LinearGradientPaint)sunGraphics2D.paint;
            return (linearGradientPaint.getFractions().length == 2 && linearGradientPaint.getCycleMethod() != MultipleGradientPaint.CycleMethod.REPEAT && linearGradientPaint.getColorSpace() != MultipleGradientPaint.ColorSpaceType.LINEAR_RGB && ((D3DGraphicsDevice)((D3DSurfaceData)sunGraphics2D.surfaceData).getDeviceConfiguration().getDevice()).isCapPresent(65536)) || super.isPaintValid(sunGraphics2D);
        }
    }
    
    private static class RadialGradient extends D3DPaints.MultiGradient
    {
    }
}
